@@ -50,7 +50,7 @@ class GetSlotName : public Command<CommandID::READ_SLOT_NAME> {
     bool isValid() const { return slot_number<0x10+3; }
       std::string dissect() const {
           std::stringstream ss;
-          ss << "slot_number:\t" << (int)(slot_number) << std::endl;
+          ss << "slot_number:\t" << static_cast<int>(slot_number) << std::endl;
           return ss.str();
       }
   } __packed;
@@ -78,7 +78,7 @@ class EraseSlot : Command<CommandID::ERASE_SLOT> {
     bool isValid() const { return !(slot_number & 0xF0); }
       std::string dissect() const {
           std::stringstream ss;
-          ss << "slot_number:\t" << (int)(slot_number) << std::endl;
+          ss << "slot_number:\t" << static_cast<int>(slot_number) << std::endl;
           return ss.str();
       }
   } __packed;
@@ -96,7 +96,7 @@ class SetTime : Command<CommandID::SET_TIME> {
     bool isValid() const { return reset && reset != 1; }
       std::string dissect() const {
           std::stringstream ss;
-          ss << "reset:\t" << (int)(reset) << std::endl;
+          ss << "reset:\t" << static_cast<int>(reset) << std::endl;
           ss << "time:\t" << (time) << std::endl;
           return ss.str();
       }
@@ -138,20 +138,20 @@ class WriteToHOTPSlot : Command<CommandID::WRITE_TO_SLOT> {
     bool isValid() const { return !(slot_number & 0xF0); }
     std::string dissect() const {
         std::stringstream ss;
-        ss << "slot_number:\t" << (int)(slot_number) << std::endl;
+        ss << "slot_number:\t" << static_cast<int>(slot_number) << std::endl;
         print_to_ss_volatile(slot_name);
         print_to_ss_volatile(slot_secret);
-        ss << "slot_config:\t" << std::bitset<8>((int)_slot_config) << std::endl;
+        ss << "slot_config:\t" << std::bitset<8>(static_cast<int>(_slot_config)) << std::endl;
         ss << "\tuse_8_digits(0):\t" << use_8_digits << std::endl;
         ss << "\tuse_enter(1):\t" << use_enter << std::endl;
         ss << "\tuse_tokenID(2):\t" << use_tokenID << std::endl;
 
         ss << "slot_token_id:\t";
         for (auto i : slot_token_id)
-            ss << std::hex << std::setw(2) << std::setfill('0')<< (int) i << " " ;
+            ss << std::hex << std::setw(2) << std::setfill('0')<< static_cast<int>(i) << " " ;
         ss << std::endl;
-        ss << "slot_counter:\t[" << (int)slot_counter << "]\t"
-         << ::nitrokey::misc::hexdump((const uint8_t *)(&slot_counter), sizeof slot_counter, false);
+        ss << "slot_counter:\t[" << static_cast<int>(slot_counter) << "]\t"
+         << ::nitrokey::misc::hexdump(reinterpret_cast<const uint8_t *>(&slot_counter), sizeof slot_counter, false);
 
       return ss.str();
     }
@@ -189,15 +189,15 @@ class WriteToTOTPSlot : Command<CommandID::WRITE_TO_SLOT> {
     bool isValid() const { return !(slot_number & 0xF0); } //TODO check
       std::string dissect() const {
           std::stringstream ss;
-          ss << "slot_number:\t" << (int)(slot_number) << std::endl;
+          ss << "slot_number:\t" << static_cast<int>(slot_number) << std::endl;
           print_to_ss_volatile(slot_name);
           print_to_ss_volatile(slot_secret);
-          ss << "slot_config:\t" << std::bitset<8>((int)_slot_config) << std::endl;
+          ss << "slot_config:\t" << std::bitset<8>(static_cast<int>(_slot_config)) << std::endl;
           ss << "slot_token_id:\t";
           for (auto i : slot_token_id)
-              ss << std::hex << std::setw(2) << std::setfill('0')<< (int) i << " " ;
+              ss << std::hex << std::setw(2) << std::setfill('0')<< static_cast<int>(i) << " " ;
           ss << std::endl;
-          ss << "slot_interval:\t" << (int)slot_interval << std::endl;
+          ss << "slot_interval:\t" << static_cast<int>(slot_interval) << std::endl;
           return ss.str();
       }
   } __packed;
@@ -217,10 +217,10 @@ class GetTOTP : Command<CommandID::GET_CODE> {
     bool isValid() const { return !(slot_number & 0xF0); }
     std::string dissect() const {
       std::stringstream ss;
-      ss << "slot_number:\t" << (int)(slot_number) << std::endl;
+      ss << "slot_number:\t" << static_cast<int>(slot_number) << std::endl;
       ss << "challenge:\t" << (challenge) << std::endl;
       ss << "last_totp_time:\t" << (last_totp_time) << std::endl;
-      ss << "last_interval:\t" << (int)(last_interval) << std::endl;
+      ss << "last_interval:\t" << static_cast<int>(last_interval) << std::endl;
       return ss.str();
     }
   } __packed;
@@ -245,7 +245,7 @@ class GetTOTP : Command<CommandID::GET_CODE> {
     std::string dissect() const {
       std::stringstream ss;
       ss << "code:\t" << (code) << std::endl;
-        ss << "slot_config:\t" << std::bitset<8>((int)_slot_config) << std::endl;
+        ss << "slot_config:\t" << std::bitset<8>(static_cast<int>(_slot_config)) << std::endl;
         ss << "\tuse_8_digits(0):\t" << use_8_digits << std::endl;
         ss << "\tuse_enter(1):\t" << use_enter << std::endl;
         ss << "\tuse_tokenID(2):\t" << use_tokenID << std::endl;
@@ -265,7 +265,7 @@ class GetHOTP : Command<CommandID::GET_CODE> {
     bool isValid() const { return (slot_number & 0xF0); }
     std::string dissect() const {
       std::stringstream ss;
-      ss << "slot_number:\t" << (int)(slot_number) << std::endl;
+      ss << "slot_number:\t" << static_cast<int>(slot_number) << std::endl;
       return ss.str();
     }
   } __packed;
@@ -290,7 +290,7 @@ class GetHOTP : Command<CommandID::GET_CODE> {
     std::string dissect() const {
       std::stringstream ss;
       ss << "code:\t" << (code) << std::endl;
-        ss << "slot_config:\t" << std::bitset<8>((int)_slot_config) << std::endl;
+        ss << "slot_config:\t" << std::bitset<8>(static_cast<int>(_slot_config)) << std::endl;
         ss << "\tuse_8_digits(0):\t" << use_8_digits << std::endl;
         ss << "\tuse_enter(1):\t" << use_enter << std::endl;
         ss << "\tuse_tokenID(2):\t" << use_tokenID << std::endl;
@@ -316,7 +316,7 @@ class ReadSlot : Command<CommandID::READ_SLOT> {
 
     std::string dissect() const {
       std::stringstream ss;
-      ss << "slot_number:\t" << (int)(slot_number) << std::endl;
+      ss << "slot_number:\t" << static_cast<int>(slot_number) << std::endl;
       return ss.str();
     }
   } __packed;
@@ -350,17 +350,17 @@ class ReadSlot : Command<CommandID::READ_SLOT> {
     std::string dissect() const {
       std::stringstream ss;
       print_to_ss_volatile(slot_name);
-      ss << "slot_config:\t" << std::bitset<8>((int)_slot_config) << std::endl;
+      ss << "slot_config:\t" << std::bitset<8>(static_cast<int>(_slot_config)) << std::endl;
       ss << "\tuse_8_digits(0):\t" << use_8_digits << std::endl;
       ss << "\tuse_enter(1):\t" << use_enter << std::endl;
       ss << "\tuse_tokenID(2):\t" << use_tokenID << std::endl;
 
       ss << "slot_token_id:\t";
       for (auto i : slot_token_id)
-        ss << std::hex << std::setw(2) << std::setfill('0')<< (int) i << " " ;
+        ss << std::hex << std::setw(2) << std::setfill('0')<< static_cast<int>(i) << " " ;
       ss << std::endl;
-      ss << "slot_counter:\t[" << (int)slot_counter << "]\t"
-         << ::nitrokey::misc::hexdump((const uint8_t *)(&slot_counter), sizeof slot_counter, false);
+      ss << "slot_counter:\t[" << static_cast<int>(slot_counter) << "]\t"
+         << ::nitrokey::misc::hexdump(reinterpret_cast<const uint8_t *>(&slot_counter), sizeof slot_counter, false);
       return ss.str();
     }
   } __packed;
@@ -407,19 +407,19 @@ class GetStatus : Command<CommandID::GET_STATUS> {
       ss  << "firmware_version:\t"
           << "[" << firmware_version << "]" << "\t"
           << ::nitrokey::misc::hexdump(
-          (const uint8_t *)(&firmware_version), sizeof firmware_version, false);
+          reinterpret_cast<const uint8_t *>(&firmware_version), sizeof firmware_version, false);
       ss << "card_serial_u32:\t" << std::hex << card_serial_u32 << std::endl;
       ss << "card_serial:\t"
-         << ::nitrokey::misc::hexdump((const uint8_t *)(card_serial),
+         << ::nitrokey::misc::hexdump(reinterpret_cast<const uint8_t *>(card_serial),
                                       sizeof card_serial, false);
       ss << "general_config:\t"
-         << ::nitrokey::misc::hexdump((const uint8_t *)(general_config),
+         << ::nitrokey::misc::hexdump(reinterpret_cast<const uint8_t *>(general_config),
                                       sizeof general_config, false);
-        ss << "numlock:\t" << (int)numlock << std::endl;
-        ss << "capslock:\t" << (int)capslock << std::endl;
-        ss << "scrolllock:\t" << (int)scrolllock << std::endl;
-        ss << "enable_user_password:\t" << (bool) enable_user_password << std::endl;
-        ss << "delete_user_password:\t" << (bool) delete_user_password << std::endl;
+        ss << "numlock:\t" << static_cast<int>(numlock) << std::endl;
+        ss << "capslock:\t" << static_cast<int>(capslock) << std::endl;
+        ss << "scrolllock:\t" << static_cast<int>(scrolllock) << std::endl;
+        ss << "enable_user_password:\t" << static_cast<bool>(enable_user_password) << std::endl;
+        ss << "delete_user_password:\t" << static_cast<bool>(delete_user_password) << std::endl;
 
         return ss.str();
     }
@@ -437,7 +437,7 @@ class GetPasswordRetryCount : Command<CommandID::GET_PASSWORD_RETRY_COUNT> {
     bool isValid() const { return true; }
     std::string dissect() const {
       std::stringstream ss;
-      ss << " password_retry_count\t" << (int)password_retry_count << std::endl;
+      ss << " password_retry_count\t" << static_cast<int>(password_retry_count) << std::endl;
       return ss.str();
     }
   } __packed;
@@ -455,7 +455,7 @@ class GetUserPasswordRetryCount
     bool isValid() const { return true; }
     std::string dissect() const {
       std::stringstream ss;
-      ss << " password_retry_count\t" << (int)password_retry_count << std::endl;
+      ss << " password_retry_count\t" << static_cast<int>(password_retry_count) << std::endl;
       return ss.str();
     }
   } __packed;
@@ -467,10 +467,10 @@ class GetUserPasswordRetryCount
     template <typename T, typename Q, int N>
     void write_array(T &ss, Q (&arr)[N]){
         for (int i=0; i<N; i++){
-            ss << std::hex << std::setfill('0') << std::setw(2) << (int)arr[i] << " ";
+            ss << std::hex << std::setfill('0') << std::setw(2) << static_cast<int>(arr[i]) << " ";
         }
         ss << std::endl;
-    };
+    }
 
 
 class GetPasswordSafeSlotStatus : Command<CommandID::GET_PW_SAFE_SLOT_STATUS> {
@@ -499,7 +499,7 @@ class GetPasswordSafeSlotName : Command<CommandID::GET_PW_SAFE_SLOT_NAME> {
     bool isValid() const { return !(slot_number & 0xF0); }
     std::string dissect() const {
       std::stringstream ss;
-      ss << "slot_number\t" << (int)slot_number << std::endl;
+      ss << "slot_number\t" << static_cast<int>(slot_number) << std::endl;
       return ss.str();
     }
   } __packed;
@@ -528,7 +528,7 @@ class GetPasswordSafeSlotPassword
     bool isValid() const { return !(slot_number & 0xF0); }
     std::string dissect() const {
       std::stringstream ss;
-      ss << "   slot_number\t" << (int)slot_number << std::endl;
+      ss << "   slot_number\t" << static_cast<int>(slot_number) << std::endl;
       return ss.str();
     }
   } __packed;
@@ -557,7 +557,7 @@ class GetPasswordSafeSlotLogin
     bool isValid() const { return !(slot_number & 0xF0); }
     std::string dissect() const {
       std::stringstream ss;
-      ss << "   slot_number\t" << (int)slot_number << std::endl;
+      ss << "   slot_number\t" << static_cast<int>(slot_number) << std::endl;
       return ss.str();
     }
   } __packed;
@@ -587,7 +587,7 @@ class SetPasswordSafeSlotData : Command<CommandID::SET_PW_SAFE_SLOT_DATA_1> {
     bool isValid() const { return !(slot_number & 0xF0); }
       std::string dissect() const {
           std::stringstream ss;
-          ss << " slot_number\t" << (int)slot_number << std::endl;
+          ss << " slot_number\t" << static_cast<int>(slot_number) << std::endl;
           print_to_ss_volatile(slot_name);
           print_to_ss_volatile(slot_password);
           return ss.str();
@@ -607,7 +607,7 @@ class SetPasswordSafeSlotData2 : Command<CommandID::SET_PW_SAFE_SLOT_DATA_2> {
     bool isValid() const { return !(slot_number & 0xF0); }
       std::string dissect() const {
         std::stringstream ss;
-        ss << " slot_number\t" << (int)slot_number << std::endl;
+        ss << " slot_number\t" << static_cast<int>(slot_number) << std::endl;
         print_to_ss_volatile(slot_login_name);
         return ss.str();
       }
@@ -625,7 +625,7 @@ class ErasePasswordSafeSlot : Command<CommandID::PW_SAFE_ERASE_SLOT> {
     bool isValid() const { return !(slot_number & 0xF0); }
       std::string dissect() const {
           std::stringstream ss;
-          ss << " slot_number\t" << (int)slot_number << std::endl;
+          ss << " slot_number\t" << static_cast<int>(slot_number) << std::endl;
           return ss.str();
       }
 
@@ -696,11 +696,11 @@ class WriteGeneralConfig : Command<CommandID::WRITE_CONFIG> {
 
     std::string dissect() const {
           std::stringstream ss;
-          ss << "numlock:\t" << (int)numlock << std::endl;
-          ss << "capslock:\t" << (int)capslock << std::endl;
-          ss << "scrolllock:\t" << (int)scrolllock << std::endl;
-          ss << "enable_user_password:\t" << (bool) enable_user_password << std::endl;
-          ss << "delete_user_password:\t" << (bool) delete_user_password << std::endl;
+          ss << "numlock:\t" << static_cast<int>(numlock) << std::endl;
+          ss << "capslock:\t" << static_cast<int>(capslock) << std::endl;
+          ss << "scrolllock:\t" << static_cast<int>(scrolllock) << std::endl;
+          ss << "enable_user_password:\t" << static_cast<bool>(enable_user_password) << std::endl;
+          ss << "delete_user_password:\t" << static_cast<bool>(delete_user_password) << std::endl;
           return ss.str();
       }
   } __packed;
