@@ -18,16 +18,25 @@ along with libnitrokey. If not, see <http://www.gnu.org/licenses/>.
 
 SPDX-License-Identifier: LGPL-3.0
 """
+import time
+from binascii import hexlify
+from math import floor
 
 import pytest
 
 from conftest import skip_if_device_version_lower_than
-from constants import DefaultPasswords, DeviceErrorCode, RFC_SECRET, bbRFC_SECRET, LibraryErrors, HOTP_slot_count, \
+from constants import DefaultPasswords, DeviceErrorCode, RFC_SECRET, bbRFC_SECRET, HOTP_slot_count, \
     TOTP_slot_count
 from helpers import helper_PWS_get_slotname, helper_PWS_get_loginname, helper_PWS_get_pass
 from misc import ffi, gs, wait, cast_pointer_to_tuple, has_binary_counter, bb
 from misc import is_storage
 
+
+@pytest.mark.aes
+def test_regenerate_aes_key_2(C):
+    test_regenerate_aes_key(C)
+
+
 @pytest.mark.lock_device
 @pytest.mark.PWS
 def test_enable_password_safe(C):
@@ -161,9 +170,13 @@ def test_enable_password_safe_after_factory_reset(C):
     if is_storage(C):
         assert C.NK_clear_new_sd_card_warning(DefaultPasswords.ADMIN) == DeviceErrorCode.STATUS_OK
     enable_password_safe_result = C.NK_enable_password_safe(DefaultPasswords.USER)
-    assert enable_password_safe_result == DeviceErrorCode.STATUS_AES_DEC_FAILED \
-           or is_storage(C) and enable_password_safe_result in \
-           [DeviceErrorCode.WRONG_PASSWORD, DeviceErrorCode.STATUS_UNKNOWN_ERROR]  # UNKNOWN_ERROR since v0.51
+    pro_case = enable_password_safe_result in [DeviceErrorCode.STATUS_AES_DEC_FAILED,
+                                               DeviceErrorCode.STATUS_AES_CREATE_KEY_FAILED]  # STATUS_AES_CREATE_KEY_FAILED since v0.14
+    storage_case = enable_password_safe_result in [DeviceErrorCode.WRONG_PASSWORD,
+                                                   DeviceErrorCode.STATUS_UNKNOWN_ERROR]  # UNKNOWN_ERROR since v0.51
+    assert not is_storage(C) and pro_case \
+           or is_storage(C) and storage_case
+    C.NK_build_aes_key(DefaultPasswords.ADMIN) == DeviceErrorCode.STATUS_OK
     assert C.NK_build_aes_key(DefaultPasswords.ADMIN) == DeviceErrorCode.STATUS_OK
     assert C.NK_enable_password_safe(DefaultPasswords.USER) == DeviceErrorCode.STATUS_OK
 
@@ -243,6 +256,7 @@ def test_admin_retry_counts(C):
 @pytest.mark.lock_device
 @pytest.mark.pin
 def test_user_retry_counts_change_PIN(C):
+    # TODO can get device with AES key not set, and fail because of that - generate the key or reorder tests
     assert C.NK_change_user_PIN(DefaultPasswords.USER, DefaultPasswords.USER) == DeviceErrorCode.STATUS_OK
     wrong_password = b'wrong_password'
     default_user_retry_count = 3
@@ -659,13 +673,13 @@ def test_read_write_config(C):
     assert not config_st.disable_user_password
 
     # use structs: write
-    config_st.numlock = 3
+    config_st.numlock = 0xFF
     assert C.NK_write_config_struct(config_st[0], DefaultPasswords.ADMIN_TEMP) == DeviceErrorCode.STATUS_OK
 
     # use structs: read II
     err = C.NK_read_config_struct(config_st)
     assert err == 0
-    assert config_st.numlock == 3
+    assert config_st.numlock == 0xFF
     assert config_st.capslock == 1
     assert config_st.scrolllock == 2
     assert config_st.enable_user_password
@@ -1070,3 +1084,35 @@ def test_OTP_all_rw(C):
         all_codes.append(this_loop_codes)
     from pprint import pprint
     pprint(all_codes)
+
+
+@pytest.mark.parametrize("count",[16, 32, 50, 51])
+def test_random(C, count):
+    skip_if_device_version_lower_than({'P': 14, 'S': 99})
+    data = ffi.new('struct GetRandom_t *')
+    req_count = count
+    res = C.NK_get_random(req_count, data)
+    assert res == DeviceErrorCode.STATUS_OK
+    assert C.NK_get_last_command_status() == DeviceErrorCode.STATUS_OK
+    assert data.op_success == 1
+    assert data.size_effective == req_count
+    print(f'{hexlify(bytes(data.data))}')
+
+
+def test_random_collect(C):
+    skip_if_device_version_lower_than({'P': 14, 'S': 99})
+    collected = b''
+    data = ffi.new('struct GetRandom_t *')
+    req_count = 50
+    tic = time.perf_counter()
+    for i in range(1024//req_count+1):
+        res = C.NK_get_random(req_count, data)
+        assert res == DeviceErrorCode.STATUS_OK
+        assert C.NK_get_last_command_status() == DeviceErrorCode.STATUS_OK
+        assert data.op_success == 1
+        assert data.size_effective == req_count
+        collected += bytes(data.data)
+    toc = time.perf_counter()
+    assert len(collected) > 1024
+    print(hexlify(collected))
+    print(f'Time used to collect {len(collected)} bytes: {round(toc-tic,2)} -> {floor(len(collected) / (toc-tic))} Bps')
